@@ -30,6 +30,9 @@ from sentry.utils.queue import maybe_delay
 
 logger = logging.getLogger('sentry.errors.coreapi')
 
+MAX_CULPRIT_LENGTH = 200
+MAX_MESSAGE_LENGTH = 1000
+
 RESERVED_FIELDS = (
     'project',
     'event_id',
@@ -262,9 +265,18 @@ def validate_data(project, data, client=None):
 
     if not data.get('message'):
         data['message'] = '<no message value>'
+    elif len(data['message']) > MAX_MESSAGE_LENGTH:
+        raise InvalidData('Value \'message\' is too long. Input is %d chars, max is %s.' % (
+            len(data['message']), MAX_MESSAGE_LENGTH))
 
-    if 'event_id' not in data:
+    if data.get('culprit') and len(data['culprit']) > 200:
+        raise InvalidData('Value \'culprit\' is too long. Input is %d chars, max is %s.' % (
+            len(data['culprit']), MAX_CULPRIT_LENGTH))
+
+    if not data.get('event_id'):
         data['event_id'] = uuid.uuid4().hex
+    elif len(data['event_id']) > 32:
+        raise InvalidData('Invalid value for \'event_id\': must be a 32 character identifier')
 
     if 'timestamp' in data:
         try:
