@@ -74,8 +74,6 @@ def get_context(lineno, context_line, pre_context=None, post_context=None, filen
             return mark_safe(highlight(line, lexer, formatter))
 
         context = tuple((n, format(l)) for n, l in context)
-    else:
-        context = tuple((n, '<pre>%s</pre>' % (mark_safe(l),)) for n, l in context)
 
     return context
 
@@ -155,6 +153,8 @@ class Message(Interface):
     If your message cannot be parameterized, then the message interface
     will serve no benefit.
 
+    - ``message`` must be no more than 1000 characters in length.
+
     >>> {
     >>>     "message": "My raw message with interpreted strings like %s",
     >>>     "params": ["this"]
@@ -162,6 +162,8 @@ class Message(Interface):
     """
 
     def __init__(self, message, params=()):
+        assert len(message) <= 1000
+
         self.message = message
         self.params = params
 
@@ -256,8 +258,6 @@ class Stacktrace(Interface):
       the framework's library once you start handling code likely are.
     ``vars``
       A mapping of variables which were available within this frame (usually context-locals).
-    ``extra``
-      A mapping of arbitrary annotated data. Platform-specific.
 
     >>> {
     >>>     "frames": [{
@@ -287,21 +287,39 @@ class Stacktrace(Interface):
     def __init__(self, frames):
         self.frames = frames
         for frame in frames:
+            # if for some reason the user provided abs_path but not filename
+            # let it through and fix it for them
+            if 'abs_path' in frame and 'filename' not in frame:
+                frame['filename'] = frame.pop('abs_path', None)
+
             # ensure we've got the correct required values
-            assert 'filename' in frame
+            assert frame.get('filename')
 
             # lineno should be an int
             if 'lineno' in frame:
-                frame['lineno'] = int(frame['lineno'])
+                if frame['lineno'] is None:
+                    del frame['lineno']
+                else:
+                    frame['lineno'] = int(frame['lineno'])
 
             # colno should be an int
             if 'colno' in frame:
-                frame['colno'] = int(frame['colno'])
+                if frame['colno'] is None:
+                    del frame['colno']
+                else:
+                    frame['colno'] = int(frame['colno'])
 
             # in_app should be a boolean
             if 'in_app' in frame:
                 frame['in_app'] = bool(frame['in_app'])
 
+            abs_path = frame.get('abs_path') or frame['filename']
+            if abs_path.startswith(('http:', 'https:')):
+                urlparts = urlparse.urlparse(abs_path)
+                if urlparts.path:
+                    frame['abs_path'] = abs_path
+                    frame['filename'] = urlparts.path
+
     def serialize(self):
         return {
             'frames': self.frames,
