@@ -49,12 +49,12 @@ from sentry.utils.strings import truncatechars
 __all__ = ('Event', 'Group', 'Project', 'SearchDocument')
 
 
-def slugify_instance(inst, label):
+def slugify_instance(inst, label, **kwargs):
     base_slug = slugify(label)
     manager = type(inst).objects
     inst.slug = base_slug
     n = 0
-    while manager.filter(slug=inst.slug).exists():
+    while manager.filter(slug=inst.slug, **kwargs).exists():
         n += 1
         inst.slug = base_slug + '-' + str(n)
 
@@ -153,7 +153,7 @@ class Project(Model):
         for p in PLATFORM_LIST
     ) + (('other', 'Other'),)
 
-    slug = models.SlugField(unique=True, null=True)
+    slug = models.SlugField(null=True)
     name = models.CharField(max_length=200)
     owner = models.ForeignKey(User, related_name="sentry_owned_project_set", null=True)
     team = models.ForeignKey(Team, null=True)
@@ -170,11 +170,14 @@ class Project(Model):
         'slug',
     ])
 
-    __repr__ = sane_repr('slug', 'owner_id')
+    class Meta:
+        unique_together = (('team', 'slug'),)
+
+    __repr__ = sane_repr('team_id', 'slug', 'owner_id')
 
     def save(self, *args, **kwargs):
         if not self.slug:
-            slugify_instance(self, self.name)
+            slugify_instance(self, self.name, team=self.team)
         super(Project, self).save(*args, **kwargs)
 
     def delete(self):
@@ -368,7 +371,7 @@ class PendingTeamMember(Model):
             logger.exception(e)
 
 
-class MessageBase(Model):
+class EventBase(Model):
     """
     Abstract base class for both Event and Group.
     """
@@ -388,7 +391,7 @@ class MessageBase(Model):
     def save(self, *args, **kwargs):
         if len(self.logger) > 64:
             self.logger = self.logger[0:61] + u"..."
-        super(MessageBase, self).save(*args, **kwargs)
+        super(EventBase, self).save(*args, **kwargs)
 
     def error(self):
         if self.message:
@@ -408,6 +411,10 @@ class MessageBase(Model):
             return self.culprit
         return truncatechars(self.message.splitlines()[0], 100)
 
+    @property
+    def team(self):
+        return self.project.team
+
     @property
     def user_ident(self):
         """
@@ -445,7 +452,7 @@ class MessageBase(Model):
         return None
 
 
-class Group(MessageBase):
+class Group(EventBase):
     """
     Aggregated message which summarizes a set of Events.
     """
@@ -465,7 +472,7 @@ class Group(MessageBase):
     objects = GroupManager()
 
     class Meta:
-        unique_together = (('project', 'logger', 'culprit', 'checksum'),)
+        unique_together = (('project', 'checksum'),)
         verbose_name_plural = _('grouped messages')
         verbose_name = _('grouped message')
         permissions = (
@@ -485,6 +492,9 @@ class Group(MessageBase):
             self.first_seen = self.last_seen
         if not self.active_at:
             self.active_at = self.first_seen
+        if self.message:
+            # We limit what we store for the message body
+            self.message = self.message.splitlines()[0][:255]
         super(Group, self).save(*args, **kwargs)
 
     @property
@@ -496,18 +506,13 @@ class Group(MessageBase):
     def natural_key(self):
         return (self.project, self.logger, self.culprit, self.checksum)
 
-    def get_absolute_url(self):
-        if self.project_id:
-            return reverse('sentry-group', kwargs={'group_id': self.pk, 'project_id': self.project.slug})
-        return '#'
-
     def get_score(self):
         return int(math.log(self.times_seen) * 600 + float(time.mktime(self.last_seen.timetuple())))
 
     def get_latest_event(self):
         if not hasattr(self, '_latest_event'):
             try:
-                self._latest_event = self.event_set.order_by('-id')[0]
+                self._latest_event = self.event_set.order_by('-datetime')[0]
             except IndexError:
                 self._latest_event = None
         return self._latest_event
@@ -560,7 +565,7 @@ class GroupMeta(Model):
     __repr__ = sane_repr('group_id', 'key', 'value')
 
 
-class Event(MessageBase):
+class Event(EventBase):
     """
     An individual event.
     """
@@ -581,11 +586,6 @@ class Event(MessageBase):
 
     __repr__ = sane_repr('project_id', 'group_id', 'checksum')
 
-    def get_absolute_url(self):
-        if self.project_id:
-            return reverse('sentry-group-event', kwargs={'group_id': self.group_id, 'event_id': self.pk, 'project_id': self.project.slug})
-        return '#'
-
     @cached_property
     def request(self):
         data = self.data
