@@ -1,3 +1,10 @@
+"""
+sentry.utils.cache
+~~~~~~~~~~~~~~~~~~
+
+:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:license: BSD, see LICENSE for more details.
+"""
 import logging
 import time
 
