@@ -11,63 +11,34 @@ from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
 from django.views.decorators.csrf import csrf_protect
 from django.views.decorators.http import require_http_methods
+from django.utils.translation import ugettext_lazy as _
 
 from sentry.constants import MEMBER_OWNER
-from sentry.models import TeamMember, ProjectKey, Team, FilterKey, Group
-from sentry.permissions import can_create_projects, can_remove_project, can_create_teams, \
-  can_add_team_member, can_add_project_key, can_remove_project_key
+from sentry.models import ProjectKey, Team, FilterKey
+from sentry.permissions import (can_create_projects, can_remove_project, can_create_teams,
+    can_add_project_key, can_remove_project_key)
 from sentry.plugins import plugins
 from sentry.plugins.helpers import set_option, get_option
 from sentry.web.decorators import login_required, has_access
-from sentry.web.forms.projects import NewProjectForm, NewProjectAdminForm,\
-  ProjectTagsForm, EditProjectForm, RemoveProjectForm, EditProjectAdminForm
+from sentry.web.forms.projects import (NewProjectForm, NewProjectAdminForm,
+    ProjectTagsForm, EditProjectForm, RemoveProjectForm, EditProjectAdminForm)
 from sentry.web.forms.teams import NewTeamForm, SelectTeamForm
-from sentry.web.helpers import render_to_response, get_project_list, \
-  plugin_config
+from sentry.web.helpers import (render_to_response, get_project_list,
+    plugin_config)
 
 
 @login_required
 @has_access
-def dashboard(request, project):
-    if not Group.objects.filter(project=project).exists():
-        return HttpResponseRedirect(reverse('sentry-get-started', args=[project.slug]))
-    return HttpResponseRedirect('%s?%s' % (reverse('sentry-stream', args=[project.slug]),
-        request.META.get('QUERY_STRING', '')))
-
-
-@login_required
-@has_access
-def get_started(request, project):
+def get_started(request, team, project):
     return render_to_response('sentry/get_started.html', {
         'project': project,
+        'team': project.team,
+        'SECTION': 'team',
+        'SUBSECTION': 'projects'
     }, request)
 
 
-@login_required
-def project_list(request):
-    project_list = get_project_list(request.user, hidden=True, select_related=["owner"]).values()
-    team_list = Team.objects.in_bulk([p.team_id for p in project_list])
-    if request.user.is_authenticated():
-        memberships = dict((tm.team_id, tm) for tm in TeamMember.objects.filter(user=request.user, team__in=team_list))
-        keys = dict((p.project_id, p) for p in ProjectKey.objects.filter(user=request.user, project__in=project_list))
-    else:
-        memberships = {}
-        keys = {}
-
-    for project in project_list:
-        key = keys.get(project.id)
-        if key:
-            project.member_dsn = key.get_dsn()
-
-        member = memberships.get(project.team_id)
-        if member:
-            project.member_type = member.get_type_display()
-
-    return render_to_response('sentry/projects/list.html', {
-        'PROJECT_LIST': project_list,
-    }, request)
-
-
+# TODO: we need a team specific project creation view, vs the "get started" view
 @login_required
 def new_project(request):
     from django.contrib.auth.models import User
@@ -123,8 +94,8 @@ def new_project(request):
         project.save()
 
         if project.platform not in (None, 'other'):
-            return HttpResponseRedirect(reverse('sentry-docs-client', args=[project.slug, project.platform]))
-        return HttpResponseRedirect(reverse('sentry-get-started', args=[project.slug]))
+            return HttpResponseRedirect(reverse('sentry-docs-client', args=[project.team.slug, project.slug, project.platform]))
+        return HttpResponseRedirect(reverse('sentry-get-started', args=[project.team.slug, project.slug]))
 
     return render_to_response('sentry/projects/new.html', {
         'project_form': project_form,
@@ -135,7 +106,7 @@ def new_project(request):
 
 @has_access(MEMBER_OWNER)
 @csrf_protect
-def remove_project(request, project):
+def remove_project(request, team, project):
     if not can_remove_project(request.user, project):
         return HttpResponseRedirect(reverse('sentry'))
 
@@ -155,12 +126,15 @@ def remove_project(request, project):
         else:
             raise ValueError(removal_type)
 
-        return HttpResponseRedirect(reverse('sentry-project-list'))
+        return HttpResponseRedirect(reverse('sentry-project-list', args=[project.team.slug]))
 
     context = csrf(request)
     context.update({
+        'team': team,
         'form': form,
         'project': project,
+        'SECTION': 'team',
+        'SUBSECTION': 'projects'
     })
 
     return render_to_response('sentry/projects/remove.html', context, request)
@@ -168,7 +142,7 @@ def remove_project(request, project):
 
 @has_access(MEMBER_OWNER)
 @csrf_protect
-def manage_project(request, project):
+def manage_project(request, team, project):
     result = plugins.first('has_perm', request.user, 'edit_project', project)
     if result is False and not request.user.has_perm('sentry.can_change_project'):
         return HttpResponseRedirect(reverse('sentry'))
@@ -191,16 +165,21 @@ def manage_project(request, project):
     if form.is_valid():
         project = form.save()
         set_option('sentry:origins', form.cleaned_data.get('origins') or [], project)
-        return HttpResponseRedirect(request.path + '?success=1')
+
+        messages.add_message(request, messages.SUCCESS,
+            _('Changes to your project were saved.'))
+
+        return HttpResponseRedirect(reverse('sentry-manage-project', args=[team.slug, project.slug]))
 
     context = csrf(request)
     context.update({
+        'team': team,
         'can_remove_project': can_remove_project(request.user, project),
         'page': 'details',
         'form': form,
         'project': project,
-        'TEAM_LIST': team_list.values(),
-        'SECTION': 'settings',
+        'SECTION': 'team',
+        'SUBSECTION': 'projects'
     })
 
     return render_to_response('sentry/projects/manage.html', context, request)
@@ -208,37 +187,7 @@ def manage_project(request, project):
 
 @has_access(MEMBER_OWNER)
 @csrf_protect
-def manage_project_team(request, project):
-    result = plugins.first('has_perm', request.user, 'edit_project', project)
-    if result is False and not request.user.has_perm('sentry.can_change_project'):
-        return HttpResponseRedirect(reverse('sentry'))
-
-    team = project.team
-
-    if not team:
-        member_list = []
-        pending_member_list = []
-    else:
-        member_list = [(tm, tm.user) for tm in team.member_set.select_related('user')]
-        pending_member_list = [(pm, pm.email) for pm in team.pending_member_set.all().order_by('email')]
-
-    context = csrf(request)
-    context.update({
-        'page': 'team',
-        'project': project,
-        'team': team,
-        'member_list': member_list,
-        'pending_member_list': pending_member_list,
-        'can_add_member': can_add_team_member(request.user, project.team),
-        'SECTION': 'settings',
-    })
-
-    return render_to_response('sentry/projects/team.html', context, request)
-
-
-@has_access(MEMBER_OWNER)
-@csrf_protect
-def manage_project_keys(request, project):
+def manage_project_keys(request, team, project):
     result = plugins.first('has_perm', request.user, 'edit_project', project)
     if result is False and not request.user.has_perm('sentry.can_change_project'):
         return HttpResponseRedirect(reverse('sentry'))
@@ -253,11 +202,13 @@ def manage_project_keys(request, project):
 
     context = csrf(request)
     context.update({
+        'team': team,
         'page': 'keys',
         'project': project,
         'key_list': key_list,
         'can_add_key': can_add_project_key(request.user, project),
-        'SECTION': 'settings',
+        'SECTION': 'team',
+        'SUBSECTION': 'projects'
     })
 
     return render_to_response('sentry/projects/keys.html', context, request)
@@ -265,38 +216,39 @@ def manage_project_keys(request, project):
 
 @has_access(MEMBER_OWNER)
 @csrf_protect
-def new_project_key(request, project):
+def new_project_key(request, team, project):
     if not can_add_project_key(request.user, project):
-        return HttpResponseRedirect(reverse('sentry-manage-project-keys', args=[project.slug]))
+        return HttpResponseRedirect(reverse('sentry-manage-project-keys', args=[project.team.slug, project.slug]))
 
     ProjectKey.objects.create(
         project=project,
         user_added=request.user,
     )
 
-    return HttpResponseRedirect(reverse('sentry-manage-project-keys', args=[project.slug]))
+    return HttpResponseRedirect(reverse('sentry-manage-project-keys', args=[project.team.slug, project.slug]))
 
 
 @require_http_methods(['POST'])
 @has_access(MEMBER_OWNER)
 @csrf_protect
-def remove_project_key(request, project, key_id):
+def remove_project_key(request, team, project, key_id):
     try:
         key = ProjectKey.objects.get(id=key_id)
     except ProjectKey.DoesNotExist:
-        return HttpResponseRedirect(reverse('sentry-manage-project-keys', args=[project.slug]))
+        return HttpResponseRedirect(reverse('sentry-manage-project-keys', args=[project.team.slug, project.slug]))
 
     if not can_remove_project_key(request.user, key):
-        return HttpResponseRedirect(reverse('sentry-manage-project-keys', args=[project.slug]))
+        return HttpResponseRedirect(reverse('sentry-manage-project-keys', args=[project.team.slug, project.slug]))
 
     key.delete()
-    messages.add_message(request, messages.SUCCESS, 'The API key (%s) was revoked.' % (key.public_key,))
+    messages.add_message(request, messages.SUCCESS,
+        _('The API key (%s) was revoked.') % (key.public_key,))
 
-    return HttpResponseRedirect(reverse('sentry-manage-project-keys', args=[project.slug]))
+    return HttpResponseRedirect(reverse('sentry-manage-project-keys', args=[project.team.slug, project.slug]))
 
 
 @has_access(MEMBER_OWNER)
-def manage_project_tags(request, project):
+def manage_project_tags(request, team, project):
     tag_list = FilterKey.objects.all_keys(project)
     if tag_list:
         form = ProjectTagsForm(project, tag_list, request.POST or None)
@@ -308,18 +260,20 @@ def manage_project_tags(request, project):
         return HttpResponseRedirect(reverse('sentry-manage-project-tags', args=[project.slug]) + '?success=1')
 
     context = {
+        'team': team,
         'tag_list': tag_list,
         'page': 'tags',
         'project': project,
         'form': form,
-        'SECTION': 'settings',
+        'SECTION': 'team',
+        'SUBSECTION': 'projects'
     }
     return render_to_response('sentry/projects/manage_tags.html', context, request)
 
 
 @has_access(MEMBER_OWNER)
 @csrf_protect
-def manage_plugins(request, project):
+def manage_plugins(request, team, project):
     result = plugins.first('has_perm', request.user, 'configure_project_plugin', project)
     if result is False and not request.user.has_perm('sentry.can_change_project'):
         return HttpResponseRedirect(reverse('sentry'))
@@ -333,9 +287,11 @@ def manage_plugins(request, project):
 
     context = csrf(request)
     context.update({
+        'team': team,
         'page': 'plugins',
         'project': project,
-        'SECTION': 'settings',
+        'SECTION': 'team',
+        'SUBSECTION': 'projects'
     })
 
     return render_to_response('sentry/projects/plugins/list.html', context, request)
@@ -343,14 +299,14 @@ def manage_plugins(request, project):
 
 @has_access(MEMBER_OWNER)
 @csrf_protect
-def configure_project_plugin(request, project, slug):
+def configure_project_plugin(request, team, project, slug):
     try:
         plugin = plugins.get(slug)
     except KeyError:
-        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.slug]))
+        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.team.slug, project.slug]))
 
     if not plugin.can_enable_for_projects():
-        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.slug]))
+        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.team.slug, project.slug]))
 
     result = plugins.first('has_perm', request.user, 'configure_project_plugin', project, plugin)
     if result is False and not request.user.is_superuser:
@@ -358,7 +314,7 @@ def configure_project_plugin(request, project, slug):
 
     form = plugin.project_conf_form
     if form is None:
-        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.slug]))
+        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.team.slug, project.slug]))
 
     action, view = plugin_config(plugin, project, request)
     if action == 'redirect':
@@ -366,13 +322,15 @@ def configure_project_plugin(request, project, slug):
 
     context = csrf(request)
     context.update({
+        'team': team,
         'page': 'plugin',
         'title': plugin.get_title(),
         'view': view,
         'project': project,
         'plugin': plugin,
         'plugin_is_enabled': plugin.is_enabled(project),
-        'SECTION': 'settings',
+        'SECTION': 'team',
+        'SUBSECTION': 'projects'
     })
 
     return render_to_response('sentry/projects/plugins/configure.html', context, request)
@@ -380,14 +338,14 @@ def configure_project_plugin(request, project, slug):
 
 @has_access(MEMBER_OWNER)
 @csrf_protect
-def reset_project_plugin(request, project, slug):
+def reset_project_plugin(request, team, project, slug):
     try:
         plugin = plugins.get(slug)
     except KeyError:
-        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.slug, slug]))
+        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug]))
 
     if not plugin.is_enabled(project):
-        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.slug, slug]))
+        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug]))
 
     result = plugins.first('has_perm', request.user, 'configure_project_plugin', project, plugin)
     if result is False and not request.user.is_superuser:
@@ -395,19 +353,19 @@ def reset_project_plugin(request, project, slug):
 
     plugin.reset_options(project=project)
 
-    return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.slug, slug]))
+    return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug]))
 
 
 @has_access(MEMBER_OWNER)
 @csrf_protect
-def enable_project_plugin(request, project, slug):
+def enable_project_plugin(request, team, project, slug):
     try:
         plugin = plugins.get(slug)
     except KeyError:
-        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.slug, slug]))
+        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug]))
 
     if plugin.is_enabled(project) or not plugin.can_enable_for_projects():
-        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.slug, slug]))
+        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug]))
 
     result = plugins.first('has_perm', request.user, 'configure_project_plugin', project, plugin)
     if result is False and not request.user.is_superuser:
@@ -415,19 +373,19 @@ def enable_project_plugin(request, project, slug):
 
     plugin.set_option('enabled', True, project)
 
-    return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.slug, slug]))
+    return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug]))
 
 
 @has_access(MEMBER_OWNER)
 @csrf_protect
-def disable_project_plugin(request, project, slug):
+def disable_project_plugin(request, team, project, slug):
     try:
         plugin = plugins.get(slug)
     except KeyError:
-        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.slug, slug]))
+        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug]))
 
     if not plugin.is_enabled(project) or not plugin.can_enable_for_projects():
-        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.slug, slug]))
+        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug]))
 
     result = plugins.first('has_perm', request.user, 'configure_project_plugin', project, plugin)
     if result is False and not request.user.is_superuser:
@@ -435,4 +393,4 @@ def disable_project_plugin(request, project, slug):
 
     plugin.set_option('enabled', False, project)
 
-    return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.slug, slug]))
+    return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug]))
